pub struct DistanceMapping { /* private fields */ }Expand description
Linear mapping of signed distance values into normalized field values.
Implementations
Sourceimpl DistanceMapping
impl DistanceMapping
Sourcepub fn from_range(range: Range) -> Self
pub fn from_range(range: Range) -> Self
Maps [range.lower, range.upper] onto [0, 1].
Sourcepub fn inverse_of_range(range: Range) -> Self
pub fn inverse_of_range(range: Range) -> Self
The inverse mapping that takes a range back from normalized values.
pub fn inverse(&self) -> Self